@@ -12,7 +12,7 @@ use feature ();
 package MooX::Pression;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.017';
+our $VERSION   = '0.018';
 
 use Keyword::Declare;
 use B::Hooks::EndOfScope;
@@ -375,7 +375,7 @@ sub _handle_factory_keyword {
 	
 	my $optim;
 	for my $attr (@$attrs) {
-		$optim = 1 if $attr =~ /^:optim\b/;
+		$optim = 1 if $attr =~ /^:optimize\b/;
 	}
 	
 	if ($via) {
@@ -415,7 +415,7 @@ sub _handle_method_keyword {
 	
 	my $optim;
 	for my $attr (@$attrs) {
-		$optim = 1 if $attr =~ /^:optim\b/;
+		$optim = 1 if $attr =~ /^:optimize\b/;
 	}
 	
 	if (defined $name) {
@@ -475,7 +475,7 @@ sub _handle_multimethod_keyword {
 	my $optim;
 	my $extra_code = '';
 	for my $attr (@$attrs) {
-		$optim = 1 if $attr =~ /^:optim\b/;
+		$optim = 1 if $attr =~ /^:optimize\b/;
 		$extra_code .= sprintf('alias=>%s', B::perlstring($1)) if $attr =~ /^:alias\((.+)\)$/;
 	}
 	
@@ -509,7 +509,7 @@ sub _handle_modifier_keyword {
 
 	my $optim;
 	for my $attr (@$attrs) {
-		$optim = 1 if $attr =~ /^:optim\b/;
+		$optim = 1 if $attr =~ /^:optimize\b/;
 	}
 
 	if ($has_sig) {
@@ -1089,7 +1089,7 @@ sub _modifier {
 #{
 #	package MooX::Pression::Anonymous::Package;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.017';
+#	our $VERSION   = '0.018';
 #	use overload q[""] => sub { ${$_[0]} }, fallback => 1;
 #	sub DESTROY {}
 #	sub AUTOLOAD {
@@ -1100,7 +1100,7 @@ sub _modifier {
 #	
 #	package MooX::Pression::Anonymous::Class;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.017';
+#	our $VERSION   = '0.018';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub new {
 #		my $me = shift;
@@ -1113,12 +1113,12 @@ sub _modifier {
 #	
 #	package MooX::Pression::Anonymous::Role;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.017';
+#	our $VERSION   = '0.018';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	
 #	package MooX::Pression::Anonymous::ParameterizableClass;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.017';
+#	our $VERSION   = '0.018';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -1132,7 +1132,7 @@ sub _modifier {
 #
 #	package MooX::Pression::Anonymous::ParameterizableRole;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.017';
+#	our $VERSION   = '0.018';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
